#include "config.h"

#include <cache/cache.h>

#include "vcc_tus_if.h"

#include "tus_file.h"
#include "tus_server.h"
#include "tus_servers.h"

struct tus_servers tus_servers[1] = { VSPLAY_INITIALIZER(tus_servers) };

VSPLAY_GENERATE(tus_servers, VPFX(tus_server), entry, tus_server_cmp);

const char *
tus_server_name(struct VPFX(tus_server) *s)
{

	CHECK_OBJ_NOTNULL(s, VMOD_TUS_SERVER_MAGIC);
	return (s->vcl_name);
}

struct tus_files *
tus_server_files(struct VPFX(tus_server) *s)
{

	CHECK_OBJ_NOTNULL(s, VMOD_TUS_SERVER_MAGIC);
	return (s->files);
}

int
tus_server_basefd(const struct VPFX(tus_server) *s)
{

	CHECK_OBJ_NOTNULL(s, VMOD_TUS_SERVER_MAGIC);
	return (s->basefd);
}

const char *
tus_server_basedir(const struct VPFX(tus_server) *s)
{

	CHECK_OBJ_NOTNULL(s, VMOD_TUS_SERVER_MAGIC);
	return (s->basedir);
}

VCL_DURATION
tus_server_expires(const struct VPFX(tus_server) *s)
{

	CHECK_OBJ_NOTNULL(s, VMOD_TUS_SERVER_MAGIC);
	return (s->expires);
}

void
tus_server_lock(struct VPFX(tus_server) *s)
{

	CHECK_OBJ_NOTNULL(s, VMOD_TUS_SERVER_MAGIC);
	AZ(pthread_mutex_lock(&s->mtx));
}

void
tus_server_unlock(struct VPFX(tus_server) *s)
{

	CHECK_OBJ_NOTNULL(s, VMOD_TUS_SERVER_MAGIC);
	AZ(pthread_mutex_unlock(&s->mtx));
}

VCL_BYTES
tus_server_max(const struct VPFX(tus_server) *s)
{

	CHECK_OBJ_NOTNULL(s, VMOD_TUS_SERVER_MAGIC);
	return (s->max);
}

struct vmod_blobdigest_digest *
tus_server_digest(const struct VPFX(tus_server) *s)
{
	CHECK_OBJ_NOTNULL(s, VMOD_TUS_SERVER_MAGIC);
	return (s->digest);
}

struct tus_exp *
tus_server_exp(const struct VPFX(tus_server) *s)
{
	CHECK_OBJ_NOTNULL(s, VMOD_TUS_SERVER_MAGIC);
	return (s->exp);
}
